@@ -1,18 +1,50 @@
 #' @include partition.R features.R context.R kwic.R S4classes.R
 NULL
 
-#' Mail result.
+#' Send the result of an analysis by Email.
 #' 
-#' Send out a mail with the statistics of an object attached as an xlsx-file.
+#' Send out a mail with the statistical analysis included in an object attached
+#' as an xlsx-file.
+#' 
+#' The method translates the result table in the object provided into an Excel sheet
+#' and attaches the sheet to an Email which will be sent to the Email-address provided
+#' by the argument \code{to}. A pre-requirement is that the global options \code{polmineR.smtp_port} and
+#' \code{polmineR.smtp_server} are validly defined. See examples.
+#' 
+#' Please note: At this stage, authentication is not yet supported.
 #' 
 #' @param .Object The object to deliver.
-#' @param to The recipient of the mail message.
-#' @param rows The number of rows of the table (if NULL, the whole table will be sent).
+#' @param to An email-address, the recipient of the mail message.
+#' @param rows The number of rows of the table included in the Excel file to be
+#'   sent (if \code{NULL}, the whole table will be sent).
 #' @param filename The filename of the (temporary) xlsx-file that is generated.
 #' @param ... Further parameters.
 #' @aliases mail mail-method
 #' @rdname mail-method
 #' @exportMethod mail
+#' @examples
+#' # Get all (global) options for the polmineR package
+#' grep("polmineR", names(options()), value = TRUE)
+#' 
+#' # Get options that need to be set
+#' getOption("polmineR.email")
+#' getOption("polmineR.smtp_server")
+#' getOption("polmineR.smtp_port")
+#' 
+#' # Sample options (let us imagine Donald Duck had a mail-account)
+#' options("polmineR.email" = "donald.duck@@duckmail.org")
+#' options("polmineR.smtp_port" = "587")
+#' options("polmineR.smtp_server" = "smtp.duckmail.org")
+#' 
+#' # This is how you send out results when options are set
+#' # (Note: Mail servers that require authentication are not yet supported.)
+#' \dontrun{
+#' y <- cooccurrences("REUTERS", query = "oil")
+#' mail(y)
+#' 
+#' k <- kwic("REUTERS", query = "oil")
+#' mail(k)
+#' }
 setGeneric("mail", function(.Object, ...) standardGeneric("mail") )
 
 
@@ -33,8 +65,9 @@ setGeneric("mail", function(.Object, ...) standardGeneric("mail") )
 #' @docType methods
 setMethod("mail", "textstat", function(.Object, to = getOption("polmineR.email"), rows = 1L:min(250L, nrow(.Object))){
   filename <- file.path(
-    tempdir(),
-    if (length(.Object@name) > 0) paste(.Object@name, "xlsx", sep = ".") else paste(is(.Object)[1], "xlsx", sep = ".")
+    normalizePath(tempdir(), winslash = "/"),
+    if (length(.Object@name) > 0) paste(.Object@name, "xlsx", sep = ".") else paste(is(.Object)[1], "xlsx", sep = "."),
+    fsep = "/"
     )
   mail(.Object@stat, to = to, filename = filename, rows = rows)
 })
@@ -58,6 +91,6 @@ setMethod("mail", "data.frame", function(.Object, to = getOption("polmineR.email
 #' @rdname mail-method
 #' @docType methods
 setMethod("mail", "kwic", function(.Object, to = getOption("polmineR.email"), rows = 1L:min(250L, nrow(.Object))){
-  filename <- file.path(tempdir(), "kwic.xlsx")
+  filename <- file.path(normalizePath(tempdir(), winslash = "/"), "kwic.xlsx", fsep = "/")
   mail(.Object@table, to = to, filename = filename, rows = rows)
 })
