@@ -27,48 +27,52 @@ NULL
 #'  ngramObject,
 #'  ngramObject[["1_pos"]] == "ADJA"  & ngramObject[["2_pos"]] == "NN"
 #'  )
-#' ngramObject2@@stat[, "1_pos" := NULL, with = FALSE][, "2_pos" := NULL, with = FALSE]
+#' ngramObject2@@stat[, "1_pos" := NULL][, "2_pos" := NULL]
 #' ngramObject3 <- sort(ngramObject2, by = "count")
 #' head(ngramObject3)
 setGeneric("ngrams", function(.Object, ...) standardGeneric("ngrams"))
 
+#' @rdname ngrams
+setMethod("ngrams", "partition", function(.Object, ...) callNextMethod(.Object, ...))
 
 #' @rdname ngrams
-setMethod("ngrams", "partition", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, ...){
+setMethod("ngrams", "character", function(.Object, ...) callNextMethod(.Object, ...))
+
+
+#' @rdname ngrams
+setMethod("ngrams", "CorpusOrSubcorpus", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, ...){
   
   if ("pAttribute" %in% names(list(...))) p_attribute <- list(...)[["pAttribute"]]
   
   if (is.null(char)){
     
-    cpos <- unlist(apply(.Object@cpos, 1, function(x) x[1]:x[2]))
-    
-    idListBase <- lapply(
+    id_list_base <- lapply(
       setNames(p_attribute, p_attribute),
-      function(pAttr) CQI$cpos2id(.Object@corpus, pAttr, cpos)
-      )
+      function(p_attr) get_token_stream(.Object, p_attribute = p_attr, decode = FALSE)
+    )
     
-    idList <- list()
-    j <- 0
-    for (i in 1:n){
-      for (pAttr in p_attribute){
-        j <- j + 1
-        idList[[j]] <- idListBase[[pAttr]][i:(length(idListBase[[pAttr]]) - (n - i))]
-        names(idList)[j] <- paste("id", i, pAttr, sep = "_")
+    id_list <- list()
+    j <- 0L
+    for (i in 1L:n){
+      for (p_attr in p_attribute){
+        j <- j + 1L
+        id_list[[j]] <- id_list_base[[p_attr]][i:(length(id_list_base[[p_attr]]) - (n - i))]
+        names(id_list)[j] <- paste("id", i, p_attr, sep = "_")
       }
     }
     
-    DT <- as.data.table(idList)
+    DT <- data.table::as.data.table(id_list)
     TF <- DT[, .N, by = c(eval(colnames(DT))), with = TRUE]
     setnames(TF, "N", "count")
-    pAttrsCols <- rep(p_attribute, times = n)
-    tokenNo <- unlist(lapply(1:n, function(x) rep(x, times = length(p_attribute))))
+    p_attrs_cols <- rep(p_attribute, times = n)
+    token_no <- unlist(lapply(1L:n, function(x) rep(x, times = length(p_attribute))))
     
     # convert ids to strings
     dummy <- lapply(
-      1:(n * length(p_attribute)),
+      1L:(n * length(p_attribute)),
       function(i){
-        str <- as.nativeEnc(CQI$id2str(.Object@corpus, pAttrsCols[i], TF[[i]]), from = .Object@encoding)
-        TF[, eval(paste(tokenNo[i], pAttrsCols[i], sep = "_")) := str , with = TRUE] 
+        str <- as.nativeEnc(CQI$id2str(corpus(.Object), p_attrs_cols[i], TF[[i]]), from = encoding(.Object))
+        TF[, eval(paste(token_no[i], p_attrs_cols[i], sep = "_")) := str , with = TRUE] 
       })
     
     # remove columns with ids
@@ -78,30 +82,30 @@ setMethod("ngrams", "partition", function(.Object, n = 2, p_attribute = "word",
     )
     setcolorder(TF, neworder = c(colnames(TF)[!colnames(TF) %in% "count"], "count"))
   } else {
-    charSoupBase <- get_token_stream(.Object, p_attribute = p_attribute[1], collapse = "")
-    charSoup <- unlist(strsplit(charSoupBase, ""))
+    char_soup_base <- get_token_stream(.Object, p_attribute = p_attribute[1], collapse = "")
+    char_soup <- unlist(strsplit(char_soup_base, ""))
     if (char[1] != ""){
-      charSoup <- unname(unlist(sapply(charSoup, function(x) ifelse(x %in% char, x, NA))))
-      if (any(is.na(charSoup))) charSoup[-which(is.na(charSoup))]
+      char_soup <- unname(unlist(sapply(char_soup, function(x) ifelse(x %in% char, x, NA))))
+      if (any(is.na(char_soup))) char_soup[-which(is.na(char_soup))]
     }
-    charSoup <- paste(charSoup[which(!is.na(charSoup))], sep = "", collapse = "")
-    charSoupTotal <- nchar(charSoup)
+    char_soup <- paste(char_soup[which(!is.na(char_soup))], sep = "", collapse = "")
+    char_soup_total <- nchar(char_soup)
     ngrams <- sapply(
-      1:(charSoupTotal - n + 1),
+      1L:(char_soup_total - n + 1L),
       function(x) {
-        if (progress) .progressBar(x, charSoupTotal)
-        substr(charSoup, x, x + n - 1)
+        if (progress) .progressBar(x, char_soup_total)
+        substr(char_soup, x, x + n - 1L)
         })
-    tabledNgrams <- table(ngrams)
+    tabled_ngrams <- table(ngrams)
     TF <- data.table(
-      ngram = names(tabledNgrams),
-      count = unname(as.vector(tabledNgrams))
+      ngram = names(tabled_ngrams),
+      count = unname(as.vector(tabled_ngrams))
       )
   }
   new(
     "ngrams",
-    n = as.integer(n), corpus = .Object@corpus, encoding = .Object@encoding,
-    size = as.integer(size(.Object)), stat = TF, name = .Object@name,
+    n = as.integer(n), corpus = corpus(.Object), encoding = encoding(.Object),
+    size = as.integer(size(.Object)), stat = TF, name = name(.Object),
     p_attribute = if (is.null(char)) p_attribute else "ngram"
     )
 })
