@@ -2,7 +2,7 @@
 NULL
 
 
-# this file includes the partition class, the constructor function 'partition'
+# this file includes the partition class, the constructor function "partition"
 # for generating the partition class, and the helper functions used 
 # by the constructur
 
@@ -47,12 +47,13 @@ setMethod("show", "partition",
 
 #' @details The \code{split}-method will split a partition object into a
 #' \code{partition_bundle} if gap between strucs exceeds a minimum number of
-#' tokens specified by 'gap'. Relevant to split up a plenary protocol into
+#' tokens specified by \code{gap}. Relevant to split up a plenary protocol# into
 #' speeches. Note: To speed things up, the returned partitions will not include
 #' frequency lists. The lists can be prepared by applying \code{enrich} on the
 #' \code{partition_bundle} object that is returned.
 #' @param x A \code{partition} object.
-#' @param gap An integer value specifying the minimum gap between regions for performing the split.
+#' @param gap An integer value specifying the minimum gap between regions for
+#'   performing the split.
 #' @rdname partition_class
 #' @exportMethod split
 #' @docType methods
@@ -266,8 +267,8 @@ is.partition <- function(x) "partition" %in% is(x)
 #' expressions are passed into \code{grep}, i.e. the regex syntax used in R
 #' needs to be used (double backlashes etc.). If regex is \code{FALSE}, the
 #' length of the character vectors can be > 1, matching s-attributes are
-#' identifies with the operator \code{%in%}.
-#' 
+#' identifies with the operator '%in%'.
+#'
 #' The XML imported into the CWB may be "flat" or "nested". This needs to be
 #' indicated with the parameter \code{xml} (default is "flat"). If you generate
 #' a \code{partition} based on a flat XML structure, some performance gain may be
@@ -557,3 +558,76 @@ setMethod("partition", "context", function(.Object, node = TRUE){
   y
 })
 
+
+################ EXPERIMENTAL ZONE
+
+#' @details The `$`-method will assign the argument \code{name} to the slot
+#'   \code{key} and return the modified object.
+#' @examples
+#' m <- partition("GERMAPARLMINI", speaker = "Merkel", regex = TRUE)
+#' m2 <- m$speaker
+#' m2@@key
+#' @rdname partition_class
+#' @exportMethod $
+setMethod("$", "partition", function(x, name){
+  x@key <- name
+  x
+})
+
+
+#' @examples
+#' m <- partition("GERMAPARLMINI", speaker = "Merkel", regex = TRUE)
+#' m$date == "2009-10-28"
+#' @rdname partition_class
+#' @exportMethod ==
+setMethod("==", "partition", function(e1, e2){
+  partition(e1, def = setNames(object = list(e2), nm = e1@key))
+})
+
+
+
+
+#' @examples
+#' s <- partition("GERMAPARLMINI", interjection = "speech")
+#' s$party != "NA"
+#' @rdname partition_class
+#' @exportMethod !=
+setMethod("!=", "partition", function(e1, e2){
+  available <- s_attributes(e1, e1@key)
+  keep <- available[!available %in% e2]
+  partition(e1, def = setNames(object = list(keep), nm = e1@key))
+})
+
+
+
+#' @examples
+#' s <- partition("GERMAPARLMINI", interjection = "speech")
+#' s$date %in% c("2009-10-27", "2009-10-28")
+#' @rdname partition_class
+#' @exportMethod %in%
+setMethod("%in%", "partition", function(x, table){
+  partition(x, def = setNames(object = list(table), nm = x@key))
+})
+
+
+#' @examples
+#' m <- partition("GERMAPARLMINI", speaker = "Merkel", regex = TRUE)
+#' y <- zoom(m, date == "2009-10-28")
+#' 
+#' speeches <- partition("GERMAPARLMINI", interjection = "speech")
+#' m <- zoom(speeches, date == "2009-10-28" & speaker == "Angela Dorothea Merkel")
+#' 
+#' not_unknown <- zoom(speeches, party != c("NA", "FDP"))
+#' s_attributes(not_unknown, "party")
+#' @rdname partition_class
+#' @exportMethod subset
+setMethod("zoom", "partition", function(x, ...){
+  cmds <- strsplit(deparse(substitute(...)), split = "\\s*&\\s*")[[1]]
+  x_s_attributes <- s_attributes(x)
+  for (cmd in cmds){
+    for (s_attr in x_s_attributes) cmd <- gsub(sprintf("(%s)", s_attr), "x$\\1", cmd)
+    x <- eval(parse(text = cmd))
+  }
+  x
+})
+
